# python-dependency-injection

### Step to publish open source

1. Install and run build

`python -m build`

2. Install Twine

```pip install twine```

3. Upload source

```twine upload dist/*```

### **Usage:**

`pip install qpvdi`
